##################
Transmission class
##################

.. |br| raw:: html

   <br />

Transmission components transmit commodities between locations.

**Transmission class description:**

.. automodule:: transmission
.. autoclass:: Transmission
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Transmission
   :parts: 1

|

**TransmissionModel class description:**

.. autoclass:: TransmissionModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: TransmissionModel
   :parts: 1